@@ -10,8 +10,8 @@ See the cf-plot home page http://ajheaps.github.io/cf-plot for a gallery of plot
 '''
 
 __author__ = 'Andy Heaps - andy.heaps@ncas.ac.uk'
-__date__ = '23rd August 2021'
-__version__ = '3.1.16'
+__date__ = '17th December 2021'
+__version__ = '3.1.18'
 
 from .cfplot import *
 
